[![Build Status](https://travis-ci.org/openworm/owmeta-core.png?branch=dev)](https://travis-ci.org/openworm/owmeta-core/builds)
[![Docs](https://readthedocs.org/projects/owmeta-core/badge/?version=latest)](https://owmeta-core.readthedocs.io/en/latest)
[![Coverage Status](https://coveralls.io/repos/github/openworm/owmeta-core/badge.svg?branch=develop)](https://coveralls.io/github/openworm/owmeta-core?branch=develop)

owmeta-core
===========
owmeta-core is a platform for sharing relational data over the internet.
